import AggregateError from "aggregate-error";
import SemanticReleaseError from "@semantic-release/error";

export default async (pluginConfig, context) => {
  const { logger, env } = context;

  const errors = []

  // Ensure we have a GitLab token
  if (!env.GITLAB_TOKEN) {
    errors.push(new SemanticReleaseError('No GitLab token specified. Set the GITLAB_TOKEN environment variable.'));
  }

  if (!env.CI_PROJECT_PATH) {
    errors.push(new SemanticReleaseError('Set the CI_PROJECT_PATH environment variable.'));
  }

  if (errors.length > 0) {
    throw new AggregateError(errors);
  }

  logger.log('Verifying GitLab API access for truncated tag creation');
};
